@@ -4,8 +4,8 @@ use crate::keyboard::ModifiersState;
 use crate::platform_impl::platform::{event_loop, util, Fullscreen, SelectedCursor};
 use crate::window::{Theme, WindowAttributes};
 use bitflags::bitflags;
-use std::io;
 use std::sync::MutexGuard;
+use std::{io, ptr};
 use windows_sys::Win32::Foundation::{HWND, RECT};
 use windows_sys::Win32::Graphics::Gdi::InvalidateRgn;
 use windows_sys::Win32::UI::WindowsAndMessaging::{
@@ -357,7 +357,7 @@ impl WindowFlags {
                     0,
                     SWP_ASYNCWINDOWPOS | SWP_NOMOVE | SWP_NOSIZE | SWP_NOACTIVATE,
                 );
-                InvalidateRgn(window, 0, false.into());
+                InvalidateRgn(window, ptr::null_mut(), false.into());
             }
         }
 
@@ -436,7 +436,7 @@ impl WindowFlags {
                 }
 
                 // Refresh the window frame
-                SetWindowPos(window, 0, 0, 0, 0, 0, flags);
+                SetWindowPos(window, ptr::null_mut(), 0, 0, 0, 0, flags);
                 SendMessageW(
                     window,
                     event_loop::SET_RETAIN_STATE_ON_SIZE_MSG_ID.get(),
@@ -459,7 +459,7 @@ impl WindowFlags {
             }
 
             util::win_to_err({
-                let b_menu = GetMenu(hwnd) != 0;
+                let b_menu = !GetMenu(hwnd).is_null();
                 if let (Some(get_dpi_for_window), Some(adjust_window_rect_ex_for_dpi)) = (
                     *util::GET_DPI_FOR_WINDOW,
                     *util::ADJUST_WINDOW_RECT_EX_FOR_DPI,
@@ -501,7 +501,7 @@ impl WindowFlags {
             let (width, height): (u32, u32) = self.adjust_size(hwnd, size).into();
             SetWindowPos(
                 hwnd,
-                0,
+                ptr::null_mut(),
                 0,
                 0,
                 width as _,
@@ -512,7 +512,7 @@ impl WindowFlags {
                     | SWP_NOMOVE
                     | SWP_NOACTIVATE,
             );
-            InvalidateRgn(hwnd, 0, false.into());
+            InvalidateRgn(hwnd, ptr::null_mut(), false.into());
         }
     }
 }
