@@ -30,7 +30,7 @@ pub struct Sugarloaf<'a> {
     pub background_color: Option<wgpu::Color>,
     pub background_image: Option<ImageProperties>,
     pub graphics: Graphics,
-    filters_brush: FiltersBrush,
+    filters_brush: Option<FiltersBrush>,
 }
 
 #[derive(Debug)]
@@ -66,6 +66,30 @@ pub struct SugarloafRenderer {
     pub power_preference: wgpu::PowerPreference,
     pub backend: wgpu::Backends,
     pub font_features: Option<Vec<String>>,
+    pub colorspace: Colorspace,
+}
+
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum Colorspace {
+    Srgb,
+    DisplayP3,
+    Rec2020,
+}
+
+#[cfg(target_os = "macos")]
+#[allow(clippy::derivable_impls)]
+impl Default for Colorspace {
+    fn default() -> Colorspace {
+        Colorspace::DisplayP3
+    }
+}
+
+#[cfg(not(target_os = "macos"))]
+#[allow(clippy::derivable_impls)]
+impl Default for Colorspace {
+    fn default() -> Colorspace {
+        Colorspace::Srgb
+    }
 }
 
 impl Default for SugarloafRenderer {
@@ -79,6 +103,7 @@ impl Default for SugarloafRenderer {
             power_preference: wgpu::PowerPreference::HighPerformance,
             backend: default_backend,
             font_features: None,
+            colorspace: Colorspace::default(),
         }
     }
 }
@@ -124,7 +149,6 @@ impl Sugarloaf<'_> {
         let quad_brush = QuadBrush::new(&ctx);
         let rich_text_brush = RichTextBrush::new(&ctx);
         let state = SugarState::new(layout, font_library, &font_features);
-        let filters_brush = FiltersBrush::default();
 
         let instance = Sugarloaf {
             state,
@@ -135,7 +159,7 @@ impl Sugarloaf<'_> {
             background_image: None,
             rich_text_brush,
             graphics: Graphics::default(),
-            filters_brush,
+            filters_brush: None,
         };
 
         Ok(instance)
@@ -206,7 +230,16 @@ impl Sugarloaf<'_> {
 
     #[inline]
     pub fn update_filters(&mut self, filters: &[Filter]) {
-        self.filters_brush.update_filters(&self.ctx, filters);
+        if filters.is_empty() {
+            self.filters_brush = None;
+        } else {
+            if self.filters_brush.is_none() {
+                self.filters_brush = Some(FiltersBrush::default());
+            }
+            if let Some(ref mut brush) = self.filters_brush {
+                brush.update_filters(&self.ctx, filters);
+            }
+        }
     }
 
     #[inline]
@@ -342,7 +375,6 @@ impl Sugarloaf<'_> {
                 let view = frame
                     .texture
                     .create_view(&wgpu::TextureViewDescriptor::default());
-
                 if let Some(layer) = &self.graphics.bottom_layer {
                     self.layer_brush
                         .prepare(&mut encoder, &mut self.ctx, &[&layer.data]);
@@ -403,10 +435,8 @@ impl Sugarloaf<'_> {
                             self.layer_brush.render(request, &mut rpass, None);
                         }
                     }
-
                     self.quad_brush
                         .render(&mut self.ctx, &self.state, &mut rpass);
-
                     self.rich_text_brush.render(&mut self.ctx, &mut rpass);
                 }
 
@@ -417,13 +447,14 @@ impl Sugarloaf<'_> {
                     self.graphics.clear_top_layer();
                 }
 
-                self.filters_brush.render(
-                    &self.ctx,
-                    &mut encoder,
-                    &frame.texture,
-                    &frame.texture,
-                );
-
+                if let Some(ref mut filters_brush) = self.filters_brush {
+                    filters_brush.render(
+                        &self.ctx,
+                        &mut encoder,
+                        &frame.texture,
+                        &frame.texture,
+                    );
+                }
                 self.ctx.queue.submit(Some(encoder.finish()));
                 frame.present();
             }
